"Contains constants useful to the SDK."

ASTRO_API_BASE_URL_ENV_VAR = "ASTRO_API_BASE_URL"
ORGANIZATION_ID_ENV_VAR = "ASTRO_ORGANIZATION_ID"
TOKEN_ENV_VAR = "OBSERVE_API_TOKEN"
